@@ -80,7 +80,7 @@ save_offset (gint nXOff, gint nYOff)
 	return;
     }
 
-    fprintf (pF, "%d:%d", nXOff, nYOff);
+    fprintf (pF, "%d:%d\n", nXOff, nYOff);
 
     fclose (pF);
 
@@ -95,8 +95,7 @@ load_offset (gint * nXOff, gint * nYOff)
     char *szRcFile;
     FILE *pF;
 
-    *nXOff = 0;
-    *nYOff = 0;
+    *nXOff = *nYOff = 0;
 
     szRcFile = xfce_resource_lookup (XFCE_RESOURCE_CONFIG,
                                      RCDIR G_DIR_SEPARATOR_S RCFILE);
@@ -177,12 +176,8 @@ notify_mcs (const char *szName,
 		    case MCS_TYPE_INT:
 			if (strcmp (szName, "Window/HideOnEmpty") == 0)
 			{
-			    if (pmcsas->data.v_int == 0)
-				ls_iconboxwin_set_hide_on_empty (plsibw,
-								 FALSE);
-			    else if (pmcsas->data.v_int == 1)
-				ls_iconboxwin_set_hide_on_empty (plsibw,
-								 TRUE);
+                            ls_iconboxwin_set_hide_on_empty (plsibw,
+                                    pmcsas->data.v_int != 0);
 			}
 			else if (strcmp (szName, "Window/Offset/X") == 0)
 			{
@@ -215,6 +210,8 @@ notify_mcs (const char *szName,
 			}
 			else if (strcmp (szName, "Window/Orientation") == 0)
 			{
+                            ls_iconboxwin_set_offset (plsibw, 0, 0);
+
 			    ls_iconboxwin_set_orientation (plsibw,
 							   pmcsas->data.
 							   v_int);
@@ -380,11 +377,10 @@ main (int ncArg, char *aszArgv[])
 
     if (!(session_managed = session_init (client_session)))
     {
-	g_message ("%s: Running without session manager", PACKAGE);
+/*	g_message ("%s: Running without session manager", PACKAGE);*/
     }
 
     pScreen = netk_screen_get_default ();
-    netk_screen_force_update (pScreen);
 
     /*
      * Netk und XFCE work is done start with the gtk code
@@ -402,8 +398,6 @@ main (int ncArg, char *aszArgv[])
 			      plsibw);
 #endif
 
-    netk_gtk_window_set_dock_type (GTK_WINDOW (plsibw));
-
     ls_iconboxwin_show (plsibw);
 
     pmcsClient =
@@ -433,9 +427,9 @@ main (int ncArg, char *aszArgv[])
     load_offset (&nXOff, &nYOff);
     ls_iconboxwin_set_offset (plsibw, nXOff, nYOff);
 
+    netk_screen_force_update (pScreen);
+
     gtk_main ();
-    g_message ("\t-=< GAME OVER >=-");
-    g_message ("%s: normal exit", PACKAGE);
 
     return 0;
 }
